==> pmml-model-gwt-1.5.13.jar: org/dmg/pmml/general_regression/PPMatrix.java <==

package org.dmg.pmml.general_regression;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Optional;

@XmlRootElement(name = "PPMatrix", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "ppCells"
})
@JsonRootName("PPMatrix")
@JsonPropertyOrder({
    "extensions",
    "ppCells"
})
public class PPMatrix
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<PPMatrix>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "PPCell", namespace = "http://www.dmg.org/PMML-4_4")
    @Optional((org.dmg.pmml.Version.PMML_4_0))
    @JsonProperty("PPCell")
    private List<PPCell> ppCells;
    private final static long serialVersionUID = 67371268L;

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(this.extensions.size()> 0));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public PPMatrix addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasPPCells() {
        return ((this.ppCells!= null)&&(this.ppCells.size()> 0));
    }

    public List<PPCell> getPPCells() {
        if (ppCells == null) {
            ppCells = new ArrayList<PPCell>();
        }
        return this.ppCells;
    }

    public PPMatrix addPPCells(PPCell... ppCells) {
        getPPCells().addAll(Arrays.asList(ppCells));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasPPCells()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getPPCells());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}

==> pmml-model-gwt-1.6.10.jar: org/dmg/pmml/general_regression/PPMatrix.java <==

package org.dmg.pmml.general_regression;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonRootName;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import org.dmg.pmml.Extension;
import org.dmg.pmml.HasExtensions;
import org.dmg.pmml.Visitor;
import org.dmg.pmml.VisitorAction;
import org.jpmml.model.annotations.Optional;

@XmlRootElement(name = "PPMatrix", namespace = "http://www.dmg.org/PMML-4_4")
@XmlType(name = "", propOrder = {
    "extensions",
    "ppCells"
})
@JsonRootName("PPMatrix")
@JsonPropertyOrder({
    "extensions",
    "ppCells"
})
public class PPMatrix
    extends org.dmg.pmml.PMMLObject
    implements HasExtensions<PPMatrix>
{

    @XmlElement(name = "Extension", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("Extension")
    private List<Extension> extensions;
    @XmlElement(name = "PPCell", namespace = "http://www.dmg.org/PMML-4_4")
    @JsonProperty("PPCell")
    @Optional((org.dmg.pmml.Version.PMML_4_0))
    private List<PPCell> ppCells;
    private final static long serialVersionUID = 67371271L;

    @Override
    public boolean hasExtensions() {
        return ((this.extensions!= null)&&(!this.extensions.isEmpty()));
    }

    @Override
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    @Override
    public PPMatrix addExtensions(Extension... extensions) {
        getExtensions().addAll(Arrays.asList(extensions));
        return this;
    }

    public boolean hasPPCells() {
        return ((this.ppCells!= null)&&(!this.ppCells.isEmpty()));
    }

    public List<PPCell> getPPCells() {
        if (ppCells == null) {
            ppCells = new ArrayList<PPCell>();
        }
        return this.ppCells;
    }

    public PPMatrix addPPCells(PPCell... ppCells) {
        getPPCells().addAll(Arrays.asList(ppCells));
        return this;
    }

    @Override
    public VisitorAction accept(Visitor visitor) {
        VisitorAction status = visitor.visit(this);
        if (status == VisitorAction.CONTINUE) {
            visitor.pushParent(this);
            if ((status == VisitorAction.CONTINUE)&&hasExtensions()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getExtensions());
            }
            if ((status == VisitorAction.CONTINUE)&&hasPPCells()) {
                status = org.dmg.pmml.PMMLObject.traverse(visitor, getPPCells());
            }
            visitor.popParent();
        }
        if (status == VisitorAction.TERMINATE) {
            return VisitorAction.TERMINATE;
        }
        return VisitorAction.CONTINUE;
    }

}
